@@ -143,7 +143,7 @@ struct VMFunction {
   // Whether this function returns anything more than a boolean flag for
   // failures.
   bool returnsData() const {
-    return returnType == Type_Pointer || outParam != Type_Void;
+    return returnType == Type_Object || outParam != Type_Void;
   }
 
   ArgProperties argProperties(uint32_t explicitArg) const {
