@@ -9,8 +9,7 @@
 using namespace js;
 using namespace js::jit;
 
-BaselineCompilerMIPSShared::BaselineCompilerMIPSShared(JSContext* cx, TempAllocator& alloc,
+BaselineCompilerMIPSShared::BaselineCompilerMIPSShared(JSContext* cx,
+                                                       TempAllocator& alloc,
                                                        JSScript* script)
-  : BaselineCompilerShared(cx, alloc, script)
-{
-}
+    : BaselineCompilerShared(cx, alloc, script) {}
