@@ -6,23 +6,23 @@
 
 #include "jit/mips64/Bailouts-mips64.h"
 
-#include "jscntxt.h"
-#include "jscompartment.h"
+#include "vm/JSCompartment.h"
+#include "vm/JSContext.h"
 
 using namespace js;
 using namespace js::jit;
 
 BailoutFrameInfo::BailoutFrameInfo(const JitActivationIterator& activations,
                                    BailoutStack* bailout)
-  : machine_(bailout->machineState())
-{
-    uint8_t* sp = bailout->parentStackPointer();
-    framePointer_ = sp + bailout->frameSize();
-    topFrameSize_ = framePointer_ - sp;
+    : machine_(bailout->machineState()) {
+  uint8_t* sp = bailout->parentStackPointer();
+  framePointer_ = sp + bailout->frameSize();
+  topFrameSize_ = framePointer_ - sp;
 
-    JSScript* script = ScriptFromCalleeToken(((JitFrameLayout*) framePointer_)->calleeToken());
-    topIonScript_ = script->ionScript();
+  JSScript* script =
+      ScriptFromCalleeToken(((JitFrameLayout*)framePointer_)->calleeToken());
+  topIonScript_ = script->ionScript();
 
-    attachOnJitActivation(activations);
-    snapshotOffset_ = bailout->snapshotOffset();
+  attachOnJitActivation(activations);
+  snapshotOffset_ = bailout->snapshotOffset();
 }
