@@ -12,24 +12,23 @@
 namespace js {
 namespace jit {
 
-static constexpr Register BaselineFrameReg = { Registers::invalid_reg };
-static constexpr Register BaselineStackReg = { Registers::invalid_reg };
+static constexpr Register BaselineFrameReg{Registers::invalid_reg};
+static constexpr Register BaselineStackReg{Registers::invalid_reg};
 
 static constexpr ValueOperand R0 = JSReturnOperand;
 static constexpr ValueOperand R1 = JSReturnOperand;
 static constexpr ValueOperand R2 = JSReturnOperand;
 
-static constexpr Register ICTailCallReg = { Registers::invalid_reg };
-static constexpr Register ICStubReg = { Registers::invalid_reg };
+static constexpr Register ICTailCallReg{Registers::invalid_reg};
+static constexpr Register ICStubReg{Registers::invalid_reg};
 
-static constexpr Register ExtractTemp0 = { Registers::invalid_reg };
-static constexpr Register ExtractTemp1 = { Registers::invalid_reg };
+static constexpr Register ExtractTemp0{Registers::invalid_reg};
+static constexpr Register ExtractTemp1{Registers::invalid_reg};
 
-static constexpr FloatRegister FloatReg0 = { FloatRegisters::invalid_reg };
-static constexpr FloatRegister FloatReg1 = { FloatRegisters::invalid_reg };
+static constexpr FloatRegister FloatReg0 = {FloatRegisters::invalid_reg};
+static constexpr FloatRegister FloatReg1 = {FloatRegisters::invalid_reg};
 
-} // namespace jit
-} // namespace js
+}  // namespace jit
+}  // namespace js
 
 #endif /* jit_none_SharedICRegisters_none_h */
-
