@@ -4,12 +4,11 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-#include "BaselineCompiler-x64.h"
+#include "jit/x64/BaselineCompiler-x64.h"
 
 using namespace js;
 using namespace js::jit;
 
-BaselineCompilerX64::BaselineCompilerX64(JSContext *cx, HandleScript script)
-  : BaselineCompilerX86Shared(cx, script)
-{
-}
+BaselineCompilerX64::BaselineCompilerX64(JSContext* cx, TempAllocator& alloc,
+                                         JSScript* script)
+    : BaselineCompilerX86Shared(cx, alloc, script) {}
