@@ -3,17 +3,23 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-13gs
+es5id: 15.3.5.4_2-21gs
 description: >
-    Strict mode - checking access to non-strict function caller from
-    strict function (indirect eval used within strict mode)
+    Strict mode - checking access to strict function caller from
+    strict function (FunctionDeclaration defined within a
+    FunctionDeclaration inside strict mode)
 flags: [onlyStrict]
 ---*/
 
-var my_eval = eval;
+function f1() {
+    function f() {
+        gNonStrict();
+    }
+    f();
+}
 
 assert.throws(TypeError, function() {
-    my_eval("gNonStrict();");
+    f1();
 });
 
 function gNonStrict() {
