@@ -2,22 +2,21 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-57gs
+es5id: 15.3.5.4_2-78gs
 description: >
     Strict mode - checking access to strict function caller from
-    non-strict function (strict function declaration called by
-    non-strict eval)
+    non-strict function (non-strict function declaration called by
+    strict new'ed Function constructor)
 flags: [noStrict]
+features: [caller]
 ---*/
 
-function f() { "use strict"; gNonStrict(); };
+function f() { return gNonStrict();};
+(function () {"use strict"; return new Function("return f();")(); })();
 
-assert.throws(TypeError, function() {
-    eval("f();");
-});
 
 function gNonStrict() {
-    return gNonStrict.caller || gNonStrict.caller.throwTypeError;
+    return gNonStrict.caller;
 }
 
 reportCompare(0, 0);
