@@ -2,25 +2,25 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.2.3.3-4-244
+es5id: 15.2.3.3-4-240
 description: >
-    Object.getOwnPropertyDescriptor - ensure that 'set' property of
+    Object.getOwnPropertyDescriptor - ensure that 'get' property of
     returned object is data property with correct 'writable' attribute
 ---*/
 
         var obj = {};
         var fun = function () {
-            return "ownSetProperty";
+            return "ownGetProperty";
         };
         Object.defineProperty(obj, "property", {
-            set: fun,
+            get: fun,
             configurable: true
         });
 
         var desc = Object.getOwnPropertyDescriptor(obj, "property");
 
-            desc.set = "overwriteSetProperty";
+            desc.get = "overwriteGetProperty";
 
-assert.sameValue(desc.set, "overwriteSetProperty", 'desc.set');
+assert.sameValue(desc.get, "overwriteGetProperty", 'desc.get');
 
 reportCompare(0, 0);
