@@ -9,20 +9,18 @@
 
 #include "vm/NumberObject.h"
 
-#include "jsobjinlines.h"
+#include "vm/JSObject-inl.h"
 
 namespace js {
 
-inline NumberObject*
-NumberObject::create(JSContext* cx, double d, HandleObject proto /* = nullptr */)
-{
-    NumberObject* obj = NewObjectWithClassProto<NumberObject>(cx, proto);
-    if (!obj)
-        return nullptr;
-    obj->setPrimitiveValue(d);
-    return obj;
+inline NumberObject* NumberObject::create(JSContext* cx, double d,
+                                          HandleObject proto /* = nullptr */) {
+  NumberObject* obj = NewObjectWithClassProto<NumberObject>(cx, proto);
+  if (!obj) return nullptr;
+  obj->setPrimitiveValue(d);
+  return obj;
 }
 
-} // namespace js
+}  // namespace js
 
 #endif /* vm_NumberObject_inl_h */
