@@ -2,6 +2,8 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 
+from __future__ import absolute_import
+
 from contextlib import contextmanager
 import multiprocessing
 import sys
@@ -64,11 +66,31 @@ def get_disk_io_counters():
     try:
         io_counters = psutil.disk_io_counters()
     except RuntimeError:
-        io_counters = []
+        io_counters = PsutilStub().disk_io_counters()
 
     return io_counters
 
 
+def _poll(pipe, poll_interval=0.1):
+    """Wrap multiprocessing.Pipe.poll to hide POLLERR and POLLIN
+    exceptions.
+
+    multiprocessing.Pipe is not actually a pipe on at least Linux.
+    That has an effect on the expected outcome of reading from it when
+    the other end of the pipe dies, leading to possibly hanging on revc()
+    below.
+    """
+    try:
+        return pipe.poll(poll_interval)
+    except Exception:
+        # Poll might throw an exception even though there's still
+        # data to read. That happens when the underlying system call
+        # returns both POLLERR and POLLIN, but python doesn't tell us
+        # about it. So assume there is something to read, and we'll
+        # get an exception when trying to read the data.
+        return True
+
+
 def _collect(pipe, poll_interval):
     """Collects system metrics.
 
@@ -93,7 +115,7 @@ def _collect(pipe, poll_interval):
 
     sleep_interval = poll_interval
 
-    while not pipe.poll(sleep_interval):
+    while not _poll(pipe, poll_interval=sleep_interval):
         io = get_disk_io_counters()
         cpu_times = psutil.cpu_times(True)
         cpu_percent = psutil.cpu_percent(None, True)
@@ -253,7 +275,7 @@ class SystemResourceMonitor(object):
 
         self._pipe, child_pipe = multiprocessing.Pipe(True)
 
-        self._process = multiprocessing.Process(None, _collect,
+        self._process = multiprocessing.Process(target=_collect,
                                                 args=(child_pipe, poll_interval))
 
     def __del__(self):
@@ -289,26 +311,31 @@ class SystemResourceMonitor(object):
         assert self._running
         assert not self._stopped
 
-        self._pipe.send(('terminate',))
+        try:
+            self._pipe.send(('terminate',))
+        except Exception:
+            pass
         self._running = False
         self._stopped = True
 
         self.measurements = []
 
-        done = False
-
         # The child process will send each data sample over the pipe
         # as a separate data structure. When it has finished sending
         # samples, it sends a special "done" message to indicate it
         # is finished.
-        while self._pipe.poll(1.0):
-            start_time, end_time, io_diff, cpu_diff, cpu_percent, virt_mem, \
-                swap_mem = self._pipe.recv()
+
+        while _poll(self._pipe, poll_interval=0.1):
+            try:
+                start_time, end_time, io_diff, cpu_diff, cpu_percent, virt_mem, \
+                    swap_mem = self._pipe.recv()
+            except Exception:
+                # Let's assume we're done here
+                break
 
             # There should be nothing after the "done" message so
             # terminate.
             if start_time == 'done':
-                done = True
                 break
 
             io = self._io_type(*io_diff)
@@ -325,11 +352,6 @@ class SystemResourceMonitor(object):
         if self._process.is_alive():
             self._process.terminate()
             self._process.join(10)
-        else:
-            # We should have received a "done" message from the
-            # child indicating it shut down properly. This only
-            # happens if the child shuts down cleanly.
-            assert done
 
         if len(self.measurements):
             self.start_time = self.measurements[0].start
